@@ -1,5 +1,5 @@
 #!/bin/sh
 libtoolize --copy --force || exit 1
-aclocal -I .
+aclocal -I m4
 automake --foreign -a -c
 autoconf
